
#ifdef  __CA78K0R__

  #pragma    SFR             /* definition for using SFR */
  #pragma    EI              /* definition for using EI */
  #pragma    DI              /* definition for using DI */
  #pragma    NOP             /* definition for using NOP */
  #pragma    STOP            /* definition for using STOP */
  #pragma    HALT            /* definition for using HALT */
  #include   "ics2_typedef.h"
  #include   "ICS_iodefine.h"
  #include   "low_level_init.h"

#elif   __CCRL__

  #define    DI()    __DI()
  #define    EI()    __EI()
  #define    NOP()   __nop()
  #define    STOP()  __stop()
  #define    HALT()  __halt()
  #include   <stdint.h>
  #include  "iodefine.h"
  
#elif   __ICCRL78__

  void      __enable_interrupt();
  void      __disable_interrupt();
  void      __no_operation();
  #define   DI()   __disable_interrupt()
  #define   EI()   __enable_interrupt()
  #define   NOP()  __no_operation()
  #include  <intrinsics.h>
  #include  <stdint.h>
  #include  <ior5f11b7e.h>
  #include  <ior5f11b7e_ext.h>

#else
  //
#endif

#include "ics2_RL78G1F.h"

  
/*********** OPTION BYTE for EWRL78 Ver3.10 ***********/
#ifdef  __ICCRL78__
/* watchdog disabled, LVD off, 32MHz clock, OCD interface enabled             */
__root __far const uint8_t OptionByte[4] @ 0x00C0u = {0x6Eu,0x73u,0xE8u,0x85u};
#endif
  
  
//       SPEED =   2     3    4    5     6     7    15
//       @32MHz  5.33M 4.0M 3.2M 2.67M 2.29M  2.0M 1.0Mbps
#define  SPEED     2   // SPEED=2 : 5.3Mbps -> 5.333*8=42.666MHz(DTLScope)
#define  INTLEVEL  2
#define  ICSMODE   6

#define  TIME_MEASURE


/*********** KEEP DTC TABLE AREA ***********/
#ifdef  __CA78K0R__
  #pragma section @@DATA  @@DTCTBL at 0xFFD00
  char  dtc_tbl[256];
  #pragma section @@DATA  @@DATA

#elif   __CCRL__
  #pragma address dtc_tbl=0xFFD00
  char  dtc_tbl[256];

#elif   __ICCRL78__
  #pragma location=0xFFD00
  __no_init volatile char  dtc_tbl[256];

#endif


#ifdef  __CA78K0R__
    #define   port_init()   (PM1.5=0)
    #define   port_high()   (P1.5=1)
    #define   port_low()    (P1.5=0)
#elif   __CCRL__
    #define   port_init()   (PM1_bit.no5=0)
    #define   port_high()   (P1_bit.no5=1)
    #define   port_low()    (P1_bit.no5=0)
#elif   __ICCRL78__
    #define   port_init()   (PM1_bit.no5=0)
    #define   port_high()   (P1_bit.no5=1)
    #define   port_low()    (P1_bit.no5=0)
#endif

int a = 0;
int b = 0;
int c = 0;
signed char   ds = 0;
unsigned char du = 0;

int  time_start = 0;
int  time_end   = 0;
int  time_diff  = 0;
int  time_max   = 0;
int  time_min   = 30000;

//              24 32 36 48 64
// SCI0_P51_P50  o  o  o  o  o
// SCI0_P17_P16  -  o  o  o  o PIOR0.1=1
// SCI1_P02_P03  -  -  -  -  o
// SCI1_P00_P01  o  o  o  o  -
// SCI1_P72_P73  o  o  -  o  - PIOR0.5=1
// SCI2_P77_P76  -  -  -  -  o PIOR0.1=1
// SCI2_P13_P14  o  o  o  o  o

void  main(void)

{
    DI();

  #ifdef  __CA78K0R__
    low_level_init();
  #endif
    
 // 64pin ------------------------------------------------------------------------
    ics2_init(0xFD00, ICS_R5F11BLx_SCI0_P51_P50, INTLEVEL, 0x40, SPEED, ICSMODE); // OK
 // ics2_init(0xFD00, ICS_R5F11BLx_SCI0_P17_P16, INTLEVEL, 0x40, SPEED, ICSMODE); // OK PIOR0.1=1
 // ics2_init(0xFD00, ICS_R5F11BLx_SCI1_P02_P03, INTLEVEL, 0x40, SPEED, ICSMODE); // OK
 // ics2_init(0xFD00, ICS_R5F11BLx_SCI2_P77_P76, INTLEVEL, 0x40, SPEED, ICSMODE); // OK PIOR0.1=1
 // ics2_init(0xFD00, ICS_R5F11BLx_SCI2_P13_P14, INTLEVEL, 0x40, SPEED, ICSMODE); // OK

 // 48pin ------------------------------------------------------------------------
 // ics2_init(0xFD00, ICS_R5F11BGx_SCI0_P51_P50, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok 
 // ics2_init(0xFD00, ICS_R5F11BGx_SCI0_P17_P16, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok PIOR0.1=1
 // ics2_init(0xFD00, ICS_R5F11BGx_SCI1_P00_P01, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok
 // ics2_init(0xFD00, ICS_R5F11BGx_SCI1_P72_P73, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok PIOR0.5=1
 // ics2_init(0xFD00, ICS_R5F11BGx_SCI2_P13_P14, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok

 // 32pin ------------------------------------------------------------------------
 // ics2_init(0xFD00, ICS_R5F11BBx_SCI0_P51_P50, INTLEVEL, 0x40, SPEED, ICSMODE); // Ok (T5106:CN2)
 // ics2_init(0xFD00, ICS_R5F11BBx_SCI0_P17_P16, INTLEVEL, 0x40, SPEED, ICSMODE); // OK PIOR0.1=1
 // ics2_init(0xFD00, ICS_R5F11BBx_SCI1_P00_P01, INTLEVEL, 0x40, SPEED, ICSMODE); // OK
 // ics2_init(0xFD00, ICS_R5F11BBx_SCI1_P72_P73, INTLEVEL, 0x40, SPEED, ICSMODE); // OK PIOR0.5=1
 // ics2_init(0xFD00, ICS_R5F11BBx_SCI2_P13_P14, INTLEVEL, 0x40, SPEED, ICSMODE); // OK

 // 24pin ------------------------------------------------------------------------
 // ics2_init(0xFD00, ICS_R5F11B7x_SCI0_P51_P50, INTLEVEL, 0x40, SPEED, ICSMODE); // OK
 // ics2_init(0xFD00, ICS_R5F11B7x_SCI1_P00_P01, INTLEVEL, 0x40, SPEED, ICSMODE); // OK
 // ics2_init(0xFD00, ICS_R5F11B7x_SCI1_P72_P73, INTLEVEL, 0x40, SPEED, ICSMODE); // OK PIOR0.5=1
 // ics2_init(0xFD00, ICS_R5F11B7x_SCI2_P13_P14, INTLEVEL, 0x40, SPEED, ICSMODE); // OK  

  #ifdef TIME_MEASURE    
    port_init();  // output
  #endif
  
    EI();

    while (1)
    {
        int i;

        a = a + 1;
        if (a>100) { a = 0; }
        b = -a;
        c = a + a;
        ds =   (signed char)(a);
        du = (unsigned char)(a);

      #ifdef TIME_MEASURE    
        port_high();
      #endif

        ics2_watchpoint();

      #ifdef TIME_MEASURE    
        port_low();
      #endif
        
        for(i=0;i<1000;i++) { NOP(); }
    }
}


